@@ -5,7 +5,7 @@ ClusterAccuracy=function(PriorCls,CurrentCls,K=9){
   #               It has k unique numbers representing the arbitrary labels of the clustering.
   # CurrentCls    Main output of the clustering, [1:n]  numerical vector with n numbers defining the classification.
   #               It has k unique numbers representing the arbitrary labels of the clustering.              
-  # K             Maximal number of classes for computation. Default K=9.
+  # K             Maximal number of Labels for computation. Default K=9.
   # 
   # OUTPUT
   # Accuracy      Number
@@ -22,28 +22,28 @@ ClusterAccuracy=function(PriorCls,CurrentCls,K=9){
     
     NormalizeCls <- function(Cls) {# Values in Cls are consistently recoded to positive consecutive integers
       
-      uniqueClasses <- sort(na.last = T, unique(Cls))
-      numberOfClasses <- length(uniqueClasses)
+      uniqueLabels <- sort(na.last = T, unique(Cls))
+      numberOfLabels <- length(uniqueLabels)
       unique2Cls <- NULL #  initializing the vector
       
       for (i in 1:length(Cls)) {
-        # calculating the indexes of elements of Cls in uniqueClasses
-        unique2Cls <- c(unique2Cls, which(uniqueClasses == Cls[i]))
+        # calculating the indexes of elements of Cls in uniqueLabels
+        unique2Cls <- c(unique2Cls, which(uniqueLabels == Cls[i]))
       }
       
-      if (numberOfClasses > 0) {
-        normalizedClasses <- c(1:numberOfClasses)
-        normalizedCls <- normalizedClasses[unique2Cls]
+      if (numberOfLabels > 0) {
+        normalizedLabels <- c(1:numberOfLabels)
+        normalizedCls <- normalizedLabels[unique2Cls]
       }
       else {
-        normalizedClasses <- Cls
+        normalizedLabels <- Cls
       }
       
       return(normalizedCls)
     }
     ####################################################
     
-    ReduceClassesToK=function(Cls,K=9){
+    ReduceClsToK=function(Cls,K=9){
       m=length(unique(Cls))
       ClsRes1=Cls
       if(m>K){
@@ -51,8 +51,8 @@ ClusterAccuracy=function(PriorCls,CurrentCls,K=9){
         for(i in 1:p){
           ClsTmp=ClsRes1
           V=ClusterCount(ClsTmp)
-          ind=order(V$CountPerClass)
-          u=head(V$UniqueClasses[ind],2)
+          ind=order(V$CountPerCluster)
+          u=head(V$UniqueClusters[ind],2)
           ClsTmp[c(which(ClsTmp==u[1]),which(ClsTmp==u[2]))]=u[1]
           ClsRes1=ClsTmp
         }
@@ -67,17 +67,21 @@ ClusterAccuracy=function(PriorCls,CurrentCls,K=9){
     if(length(unique(givenCls))>K){
       warning('Too many clusters in CurrentCls for RAM of single PC. Combining clusters of smallest size.
             Alternatively, please use cloud Computing, e.g. SparkR')
-      givenCls=ReduceClassesToK(givenCls,K=K)
+      givenCls=ReduceClsToK(givenCls,K=K)
     }
     givenCls<- NormalizeCls(givenCls)
     
-    uniqueClasses <- sort(na.last = T, unique(c(standardCls,givenCls)))
-    requireNamespace('pracma')
-    allPossiblePermutations <- pracma::perms(uniqueClasses)
+    uniqueLabels <- sort(na.last = T, unique(c(standardCls,givenCls)))
+    if(!requireNamespace('pracma')){
+      message("ClusterAccuracy requires the package (pracma) specified in suggest to be installed. Please install this package.")
+      return(NaN)
+    }
+      
+    allPossiblePermutations <- pracma::perms(uniqueLabels)
     nrOfPermutations <- nrow(allPossiblePermutations)
-    nrOfStdClasses <- ncol(allPossiblePermutations)
-    givenClasses <- sort(na.last = T, unique(givenCls))
-    nrOfGivenClasses <- length(givenClasses)
+    nrOfStdLabels <- ncol(allPossiblePermutations)
+    givenLabels <- sort(na.last = T, unique(givenCls))
+    nrOfGivenLabels <- length(givenLabels)
     renamedCls <- givenCls
     bestAccuracy <- 0
     # For every permutation
@@ -86,12 +90,12 @@ ClusterAccuracy=function(PriorCls,CurrentCls,K=9){
       tryRenameCls <- givenCls
       
       # Set a permutation of cls to be inspected
-      newClassNames <- c(1:nrOfGivenClasses)
-      newClassNames[1:nrOfStdClasses] <- allPossiblePermutations[i,]
+      newClassNames <- c(1:nrOfGivenLabels)
+      newClassNames[1:nrOfStdLabels] <- allPossiblePermutations[i,]
       
-      for (j in 1:nrOfGivenClasses) { # For every point
+      for (j in 1:nrOfGivenLabels) { # For every point
         # Search
-        tryRenameCls[which(givenCls == givenClasses[j])] <- newClassNames[j]
+        tryRenameCls[which(givenCls == givenLabels[j])] <- newClassNames[j]
       }
       # True positives
       accuracy <- sum(tryRenameCls == standardCls)
